<?php

namespace Drupal\a12s_page_context\Plugin\A12sPageContextFormDisplay;

use Drupal\a12s_page_context\Plugin\FormDisplayPluginBase;
use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Utility\Error;
use Drupal\system\Plugin\Condition\RequestPath;

/**
 * Plugin implementation of the a12s_page_context_form.
 *
 * @A12sPageContextFormDisplay(
 *   id = "path",
 *   label = @Translation("Path"),
 *   description = @Translation("Display the form on some specific paths")
 * )
 *
 * @noinspection AnnotationMissingUseInspection
 */
class Path extends FormDisplayPluginBase {

  use StringTranslationTrait;

  /**
   * The key used for storage (MD5 hash of settings).
   *
   * @var string|null
   */
  protected ?string $key = NULL;

  /**
   * {@inheritdoc}
   */
  public function getStorageKey(array $context): ?string {
    // We don't rely on a storage key for this plugin.
    return $context['path_key'] ?? NULL;
  }

  /**
   * {@inheritdoc}
   *
   * The path plugin may apply to any route.
   */
  public function applies(array $context): bool {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function filterRecords(array $records, array $context): array {
    return array_filter($records, function ($record) {
      if ($record->getPluginId() !== $this->getPluginId()) {
        return TRUE;
      }

      if ($settings = $record->getSettings()) {
        $requestPath = self::getRequestPathConditionPlugin($settings);
        return $requestPath->execute();
      }

      return FALSE;
    });
  }

  /**
   * Get a condition plugin instance.
   *
   * @param array $configuration
   *   The plugin configuration.
   *
   * @return \Drupal\system\Plugin\Condition\RequestPath|null
   *   The plugin instance, or NULL.
   */
  public static function getRequestPathConditionPlugin(array $configuration = []): ?RequestPath {
    try {
      $conditionManager = \Drupal::service('plugin.manager.condition');
      return $conditionManager->createInstance('request_path', $configuration);
    }
    catch (PluginException $e) {
      Error::logException(\Drupal::logger('a12s_page_context'), $e);
      return NULL;
    }
  }

}
